@@ -9,6 +9,7 @@ from os.path import abspath, basename, isfile, join
 import re
 import sys
 
+from .._vendor.auxlib.ish import dals
 from ..base.constants import CONDA_TARBALL_EXTENSION, ROOT_ENV_NAME
 from ..base.context import context, get_prefix as context_get_prefix
 from ..common.compat import iteritems
@@ -692,3 +693,13 @@ def create_prefix_spec_map_with_deps(r, specs, default_prefix):
                 if not linked_spec.name.startswith(spec) and r.depends_on(spec, linked_spec):
                     prefix_spec_map[spec_prefix].add(linked_spec.name)
     return prefix_spec_map
+
+
+def check_non_admin():
+    from ..common.platform import is_admin
+    if not context.non_admin_enabled and not is_admin():
+        from ..exceptions import OperationNotAllowed
+        raise OperationNotAllowed(dals("""
+            The create, install, update, and remove operations have been disabled
+            on your system for non-privileged users.
+        """))
